@@ -117,22 +117,27 @@ sig
   type t
 
   (** Exception raised when trying to wake_up a task 
-    * that has been previously stoped *)
-  exception Stoped
+    * that has been previously stopped *)
+  exception Stopped
 
   (** [add ~priority s f] creates an asynchronous task in [s] with
     * priority [priority].
     *
-    * The task executes the function [f], and go to sleep.
-    * Use [wake_up] to resume the task and execute [f] again. *)
-  val add : priority:'a -> 'a scheduler -> (unit -> unit) -> t
+    * The task executes the function [f].
+    * If the task returns a positive float, the function will be executed
+    * again after this delay. Otherwise it goes to sleep, and 
+    * you can use wake_up] to resume the task and execute [f] again. 
+    * Only a single call to [f] is done at each time. 
+    * Multiple [wake_up] while previous task has not 
+    * finished will result in sequentialized calls to [f]. *)
+  val add : priority:'a -> 'a scheduler -> (unit -> float) -> t
 
   (** Wake up an asynchronous task. 
-    * Raises [Stoped] if the task has been stoped. *)
+    * Raises [Stopped] if the task has been stopped. *)
   val wake_up : t -> unit
 
   (** Stop and remove the asynchronous task. Doesn't quit a running task. 
-    * Raises [Stoped] if the task has been stoped. *)
+    * Raises [Stopped] if the task has been stopped. *)
   val stop : t -> unit
 end
 
@@ -159,7 +164,7 @@ sig
     * [Int d] is raised when reading or writing failed.
     * the returned value is respectively the ammount of 
     * data read or written *)
-  type failure = Int of int | Unix of Unix.error*string*string
+  type failure = Int of int | Unix of Unix.error*string*string | Unknown of exn
 
   (** Wrapper to perform a read on a socket and trigger a function when
     * a marker has been detected, or enough data has been read.
